<?php
/**
 * Recent_Posts widget class
 *
 * @since 2.8.0
 */
class avaxy_widget_newss extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_news', 'description' => esc_html__( "The most recent posts on your site", 'avaxy') );
        parent::__construct('recent-posts', esc_html__('avaxy Recent Posts', 'avaxy'), $widget_ops);
        $this->alt_option_name = 'widget_news';

        
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('avaxy_widget_newss', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo $cache[ $args['widget_id'] ];
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Recent Posts', 'avaxy' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        if ( ! $number )
            $number = 10;
        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

        $r = new WP_Query( apply_filters( 'widget_posts_args', array( 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
        if ($r->have_posts()) :
?>
        <?php echo htmlspecialchars_decode(esc_attr($before_widget)); ?>
        <?php if ( $title ) echo htmlspecialchars_decode(esc_attr($before_title)) . esc_attr($title) . htmlspecialchars_decode(esc_attr($after_title)); ?>
        <div class="widget-recent-posts">
                        <ul>
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>
            <!-- blog-post -->
            <li class="blog-post">
                <!-- post -->
                <div class="post">


                    <!-- post-type -->
                    <div class="post-type">
                    <?php if ( has_post_thumbnail() ) { ?>

                        <a href="<?php the_permalink();?>" title="<?php the_title(); ?>">
                            <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Post Image" />
                        </a>
                        <?php }?>

                    </div><!-- /post-type -->


                    <!-- post-title -->
                    <div class="post-title">
                        <h5>
                            <a href="<?php the_permalink();?>" title="<?php the_title(); ?>">
                                <?php the_title(); ?>
                            </a>
                        </h5>
                    </div><!-- /post-title -->

                    <!-- post-meta -->
                    <p class="post-meta">
                        <span class="meta-date">
                            <i class="glyphicon glyphicon-time"></i>
                            <a href="#" title="Date"><?php the_time('F j, Y'); ?></a>
                        </span>
                    </p><!-- /post-meta -->


                </div><!-- /post -->
            </li><!-- /blog-post -->

        <?php endwhile; ?>
        </ul>
        </div>
        <?php echo htmlspecialchars_decode(esc_attr($after_widget)); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('avaxy_widget_newss', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_news']) )
            delete_option('widget_news');

        return $instance;
    }

    

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'avaxy' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'avaxy' ); ?></label>
        <input id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'show_date' )); ?>" />
        <label for="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>"><?php esc_html_e( 'Display post date?', 'avaxy' ); ?></label></p>
<?php
    }
}









class avaxy_widget_search extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_search', 'description' => esc_html__( "Search on your site", 'avaxy') );
        parent::__construct('search', esc_html__('avaxy Search', 'avaxy'), $widget_ops);
        $this->alt_option_name = 'widget_search';

        
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('avaxy_widget_search', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo $cache[ $args['widget_id'] ];
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Search', 'avaxy' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        ?>
        <?php echo htmlspecialchars_decode(esc_attr($before_widget)); ?>
        <div id="custom-search-input-blog">
                        <form class="input-group col-md-12" role="search" action="<?php echo esc_url(home_url('/')); ?>" method="get">
                            <input type="text" class="form-control input-lg s" placeholder="Search" name="s" value="<?php echo get_search_query() ?>">
                            <span class="input-group-btn">
                                <button class="btn-icon btn-search" type="submit">
                                    <i class="fa fa-search"></i>
                                </button>
                            </span>
                        </form>
                    </div> 

       
        
        
        <?php echo htmlspecialchars_decode(esc_attr($after_widget)); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
   

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('avaxy_widget_search', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_search']) )
            delete_option('widget_search');

        return $instance;
    }

    

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'avaxy' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

      
<?php
    }
}


class avaxy_widget_news_projects extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_news_projects', 'description' => esc_html__( "The most recent projects on your site", 'avaxy') );
        parent::__construct('recent-projects', esc_html__('avaxy Recent projects', 'avaxy'), $widget_ops);
        $this->alt_option_name = 'widget_news_projects';

        
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('avaxy_widget_news_projects', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo $cache[ $args['widget_id'] ];
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Recent projects', 'avaxy' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        if ( ! $number )
            $number = 10;
        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

        $r = new WP_Query( apply_filters( 'widget_projects_args', array( 'post_type' => 'portfolio','posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
        if ($r->have_posts()) :
?>
        <?php echo htmlspecialchars_decode(esc_attr($before_widget)); ?>
        <?php if ( $title ) echo htmlspecialchars_decode(esc_attr($before_title)) . esc_attr($title) . htmlspecialchars_decode(esc_attr($after_title)); ?>
        <div class="widget-recent-projects">
                        <ul>
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>

            <!-- portfolio-block -->
            <li class="portfolio-block">
                <!-- portfolio-item -->
                <div class="portfolio-item">

                <?php if ( has_post_thumbnail() ) { ?>


                    <!-- portfolio-item-header -->
                    <div class="portfolio-item-header">
                        <a href="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" title="Preview" class="fancybox">
                            <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Portfolio Item" />
                        </a>
                    </div><!-- /portfolio-item-header -->
                    <?php }?>


                    <!-- portfolio-item-footer -->
                    <div class="portfolio-item-footer">

                        <!-- portfolio-item-title -->
                        <div class="portfolio-item-title">
                            <h4>
                                <a href="<?php the_permalink();?>" title="<?php the_title(); ?>">
                                    <?php the_title(); ?>
                                </a>
                            </h4>
                        </div><!-- /portfolio-item-title -->

                        <!-- portfolio-item-cat -->
                        <div class="portfolio-item-cat">
                            <span><?php 
                                    $type_name='';
                                    $categories = get_the_terms(get_the_ID(),'type'); 
                                    // Show all category for post
                                    $i=1;
                                    foreach( $categories as $category) {                                 
                                    $type_name = $category->name ;
                                    $i++;
                                     
                                        echo esc_html($type_name).'  '; 
                                       } 
                                     ?></span>
                        </div><!-- /portfolio-item-cat -->

                    </div><!-- /portfolio-item-footer -->


                </div><!-- /portfolio-item -->
            </li><!-- /portfolio-block -->

        <?php endwhile; ?>
        </ul>
        </div>
        <?php echo htmlspecialchars_decode(esc_attr($after_widget)); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('avaxy_widget_news_projects', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_news']) )
            delete_option('widget_news');

        return $instance;
    }

    

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'avaxy' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'avaxy' ); ?></label>
        <input id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'show_date' )); ?>" />
        <label for="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>"><?php esc_html_e( 'Display post date?', 'avaxy' ); ?></label></p>
<?php
    }
}






function avaxy_register_custom_widgets() {
    register_widget( 'avaxy_widget_search' );
    register_widget( 'avaxy_widget_newss' );
    register_widget( 'avaxy_widget_news_projects' );
}
add_action( 'widgets_init', 'avaxy_register_custom_widgets' );    





