<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "redux_demo";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();

    if ( is_dir( $sample_patterns_path ) ) {

        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();

            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'avaxy Options', 'redux-framework-demo' ),
        'page_title'           => __( 'avaxy Options', 'redux-framework-demo' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => true,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    $args['admin_bar_links'][] = array(
        'id'    => 'redux-docs',
        'href'  => 'http://docs.reduxframework.com/',
        'title' => __( 'Documentation', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        //'id'    => 'redux-support',
        'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
        'title' => __( 'Support', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'redux-extensions',
        'href'  => 'reduxframework.com/extensions',
        'title' => __( 'Extensions', 'redux-framework-demo' ),
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
        'title' => 'Visit us on GitHub',
        'icon'  => 'el el-github'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/reduxframework',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://www.linkedin.com/company/redux-framework',
        'title' => 'Find us on LinkedIn',
        'icon'  => 'el el-linkedin'
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( __( '<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'redux-framework-demo' ), $v );
    } else {
        $args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'redux-framework-demo' );
    }

    // Add content after the form.
    $args['footer_text'] = __( '<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'redux-framework-demo' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-cogs',
                'title' => __('General Settings', 'avaxy'),
                'fields' => array(                  
                    array(
                        'id' => 'author_content',
                        'type' => 'textarea',
                        'title' => __('Author content', 'avaxy'),
                        'subtitle' => __('', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Vergatheme'
                    ),
                    array(
                        'id' => 'description_content',
                        'type' => 'textarea',
                        'title' => __('Description content', 'avaxy'),
                        'subtitle' => __('', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Country Holidays - Premium site template for a country accommodation.'
                    ),
                    array(
                        'id' => 'keywords_content',
                        'type' => 'textarea',
                        'title' => __('SEO Description', 'avaxy'),
                        'subtitle' => __('', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'farm activities, itineraries, farm holidays, country holidays, bed and breakfast, hotel, country hotel'
                    ),
                    array(
                        'id' => 'viewport_content',
                        'type' => 'textarea',
                        'title' => __('Viewport content', 'avaxy'),
                        'subtitle' => __('', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'width=device-width, initial-scale=1'
                    ),
                    array(
                        'id' => 'seo_des',
                        'type' => 'textarea',
                        'title' => __('SEO Description', 'avaxy'),
                        'subtitle' => __('', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'seo_key',
                        'type' => 'textarea',
                        'title' => __('SEO Keywords', 'avaxy'),
                        'subtitle' => __('', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => ''
                    ), 
                )
            ) );
            
            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-picture',
                'title' => __('Logo & Favicon Settings', 'avaxy'),
                'fields' => array(      
                    array(
                        'id' => 'favicon',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Custom Favicon', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('Upload your Favicon.', 'avaxy'),
                        'subtitle' => __('', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'logo',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload your logo.', 'avaxy'),
                        'default' => ''
                    ),
                    
                    array(
                        'id' => 'logo_footer',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo footer', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload your logo footer.', 'avaxy'),
                        'default' => ''
                    ),  
                    array(
                        'id' => 'logo_preload',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Image Preload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload your image preload.', 'avaxy'),
                        'default' => ''
                    ),  
                )
            ) );
            
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Blog Settings', 'avaxy'),
                'fields' => array(
                    array(
                        'id' => 'blog_text_top',
                        'type' => 'text',
                        'title' => __('Blog text top', 'avaxy'),
                        'subtitle' => __('Input Blog text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'latest news'
                    ),
                    array(
                        'id' => 'blog_title',
                        'type' => 'text',
                        'title' => __('Blog Title', 'avaxy'),
                        'subtitle' => __('Input Blog Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Our Blog'
                    ),   
                    array(
                        'id' => 'blog_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Blog image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload blog image.', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'single_title',
                        'type' => 'text',
                        'title' => __('Single Title', 'avaxy'),
                        'subtitle' => __('Input Single Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Blog single post title'
                    ),
                    array(
                        'id' => 'blog_image_single',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Blog image single Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload blog image single.', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'single_post_text',
                        'type' => 'text',
                        'title' => __('Single Post text', 'avaxy'),
                        'subtitle' => __('Input Single Post text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Single post'
                    ),  
                    array(
                        'id' => 'blog_excerpt',
                        'type' => 'text',
                        'title' => __('Blog custom excerpt leng', 'avaxy'),
                        'subtitle' => __('Input Blog custom excerpt leng', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '30'
                    ),
                    array(
                        'id' => 'continue_reading',
                        'type' => 'text',
                        'title' => __('Button Text For Post', 'avaxy'),
                        'subtitle' => __('Input Button Text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Continue reading'
                    ),
                    array(
                        'id' => 'link_share_facebook',
                        'type' => 'text',
                        'title' => __('link share facebook', 'avaxy'),
                        'subtitle' => __('link share facebook', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'link_share_twitter',
                        'type' => 'text',
                        'title' => __('link share twitter', 'avaxy'),
                        'subtitle' => __('link share twitter', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'link_share_google',
                        'type' => 'text',
                        'title' => __('link share google', 'avaxy'),
                        'subtitle' => __('link share google', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'link_share_youtube',
                        'type' => 'text',
                        'title' => __('link share youtube', 'avaxy'),
                        'subtitle' => __('link share youtube', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'link_share_behance',
                        'type' => 'text',
                        'title' => __('link share behance', 'avaxy'),
                        'subtitle' => __('link share behance', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_pinterest',
                        'type' => 'text',
                        'title' => __('link share pinterest', 'avaxy'),
                        'subtitle' => __('link share pinterest', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'link_share_dribbble',
                        'type' => 'text',
                        'title' => __('link share dribbble', 'avaxy'),
                        'subtitle' => __('link share dribbble', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),

                 )
            ) );

            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Portfolio Settings', 'avaxy'),
                'fields' => array(
                    array(
                        'id' => 'portfolio_text_top',
                        'type' => 'text',
                        'title' => __('Portfolio text top', 'avaxy'),
                        'subtitle' => __('Input Portfolio text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Creatvie'
                    ),
                    array(
                        'id' => 'portfolio_title',
                        'type' => 'text',
                        'title' => __('single Portfolio Title', 'avaxy'),
                        'subtitle' => __('Input Portfolio Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Portfolio'
                    ),   
                    array(
                        'id' => 'portfolio_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Portfolio image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload Portfolio single image.', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'portfolio_filter',
                        'type' => 'text',
                        'title' => __('Portfolio text filter', 'avaxy'),
                        'subtitle' => __('Input Portfolio text filter', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Filter By:'
                    ), 
                    array(
                        'id' => 'portfolio_template',
                        'type' => 'editor',
                        'title' => __('portfolio template', 'avaxy'),
                        'subtitle' => __('portfolio template', 'avaxy'),
                        'default' => '',
                    ),



                    // Setting with Single //
                    array(
                        'id' => 'single_portfolio_text_top',
                        'type' => 'text',
                        'title' => __('Portfolio Single text top', 'avaxy'),
                        'subtitle' => __('Input Portfolio text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Portfolio'
                    ),
                    array(
                        'id' => 'single_portfolio_title',
                        'type' => 'text',
                        'title' => __('single Portfolio Title', 'avaxy'),
                        'subtitle' => __('Input single Portfolio Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Single Project'
                    ),   
                    array(
                        'id' => 'portfolio_image_single',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Portfolio Single image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload Portfolio single image.', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'portfolio_des_text',
                        'type' => 'text',
                        'title' => __('Portfolio text description', 'avaxy'),
                        'subtitle' => __('Input Portfolio text description', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Project Description'
                    ),
                    array(
                        'id' => 'portfolio_details_text',
                        'type' => 'text',
                        'title' => __('Portfolio text details', 'avaxy'),
                        'subtitle' => __('Input Portfolio text details', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Project Details'
                    ),
                    array(
                        'id' => 'portfolio_client',
                        'type' => 'text',
                        'title' => __('Portfolio text client', 'avaxy'),
                        'subtitle' => __('Input Portfolio text client', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Client :'
                    ),
                    array(
                        'id' => 'portfolio_date',
                        'type' => 'text',
                        'title' => __('Portfolio text date', 'avaxy'),
                        'subtitle' => __('Input Portfolio text date', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Date :'
                    ),
                    array(
                        'id' => 'portfolio_skill',
                        'type' => 'text',
                        'title' => __('Portfolio text skill', 'avaxy'),
                        'subtitle' => __('Input Portfolio text skill', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Skills :'
                    ),
                    array(
                        'id' => 'portfolio_preview',
                        'type' => 'text',
                        'title' => __('Portfolio text preview', 'avaxy'),
                        'subtitle' => __('Input Portfolio text preview', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Preview :'
                    ),
                    array(
                        'id' => 'portfolio_demo',
                        'type' => 'text',
                        'title' => __('Portfolio text demo', 'avaxy'),
                        'subtitle' => __('Input Portfolio text demo', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Demo'
                    ),
                    array(
                        'id' => 'portfolio_related',
                        'type' => 'text',
                        'title' => __('Portfolio text Related', 'avaxy'),
                        'subtitle' => __('Input Portfolio text Related', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Related Projects'
                    ),
                    
                 )
            ) );


            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Team Settings', 'avaxy'),
                'fields' => array(
                    array(
                        'id' => 'team_text_top',
                        'type' => 'text',
                        'title' => __('Team text top', 'avaxy'),
                        'subtitle' => __('Input Team text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Awesome'
                    ),  
                    array(
                        'id' => 'team_title',
                        'type' => 'text',
                        'title' => __('Team Title', 'avaxy'),
                        'subtitle' => __('Input Team Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Team'
                    ), 
                    array(
                        'id' => 'team_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Team image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload gallery image.', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'team_text_contact',
                        'type' => 'text', 
                        'title' => __('Team contact description', 'avaxy'),
                        'subtitle' => __('Input Team contact description', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'AVAXY IS HTML5 TEMPLATE, WHICH CONTAINS EVERY THING YOU WANT FOR YOUR WEBSITE IN A CREATIVE WAY.'
                    ), 
                    array(
                        'id' => 'team_contact',
                        'type' => 'text', 
                        'title' => __('Team text contact', 'avaxy'),
                        'subtitle' => __('Input Team text contact', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'CONTACT ME'
                    ), 
                    array(
                        'id' => 'link_contact',
                        'type' => 'text', 
                        'title' => __('Team link contact', 'avaxy'),
                        'subtitle' => __('Input Link contact', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ), array(
                        'id' => 'team_filter',
                        'type' => 'text', 
                        'title' => __('Team text Filter', 'avaxy'),
                        'subtitle' => __('Input Team text Filter With team5', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Filter By:'
                    ), 
                    array(
                        'id' => 'team1_template',
                        'type' => 'editor',
                        'title' => __('Team1 template', 'avaxy'),
                        'subtitle' => __('Team1 template', 'avaxy'),
                        'default' => '',
                    ),
                    array(
                        'id' => 'team2_template',
                        'type' => 'editor',
                        'title' => __('team2 template', 'avaxy'),
                        'subtitle' => __('team2 template', 'avaxy'),
                        'default' => '',
                    ),
                    array(
                        'id' => 'team3_template',
                        'type' => 'editor',
                        'title' => __('team3 template', 'avaxy'),
                        'subtitle' => __('team3 template', 'avaxy'),
                        'default' => '',
                    ),
                    array(
                        'id' => 'team4_template',
                        'type' => 'editor',
                        'title' => __('team4 template', 'avaxy'),
                        'subtitle' => __('team4 template', 'avaxy'),
                        'default' => '',
                    ),
                    array(
                        'id' => 'team5_template',
                        'type' => 'editor',
                        'title' => __('team5 template', 'avaxy'),
                        'subtitle' => __('team5 template', 'avaxy'),
                        'default' => '',
                    ),
                    

                    // About Me
                    array(
                        'id' => 'single_team_text_top',
                        'type' => 'text',
                        'title' => __('Single team text top', 'avaxy'),
                        'subtitle' => __('Input Single team text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Wellcome'
                    ), 
                     array(
                        'id' => 'single_team_title',
                        'type' => 'text',
                        'title' => __('Single team title', 'avaxy'),
                        'subtitle' => __('Input Single team title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'About me'
                    ), 

                     array(
                        'id' => 'team_image_single',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Team single image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload team single image.', 'avaxy'),
                        'default' => ''
                    ),
                      array(
                        'id' => 'member_percent1',
                        'type' => 'text',
                        'title' => __('Member percent1 text', 'avaxy'),
                        'subtitle' => __('Input Member percent1 text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'HTML'
                    ), 
                       array(
                        'id' => 'member_percent2',
                        'type' => 'text',
                        'title' => __('Member percent2 text', 'avaxy'),
                        'subtitle' => __('Member percent2 text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'wordpress'
                    ), 
                        array(
                        'id' => 'member_percent3',
                        'type' => 'text',
                        'title' => __('Member percent3 text', 'avaxy'),
                        'subtitle' => __('Member percent3 text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'php'
                    ), 
                         array(
                        'id' => 'member_percent4',
                        'type' => 'text',
                        'title' => __('Member percent4 text', 'avaxy'),
                        'subtitle' => __('Member percent4 text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Joomla'
                    ), 
                          array(
                        'id' => 'member_percent5',
                        'type' => 'text',
                        'title' => __('Member percent5 text', 'avaxy'),
                        'subtitle' => __('Member percent5 text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Muse'
                    ), 
                           array(
                        'id' => 'member_percent6',
                        'type' => 'text',
                        'title' => __('Member percent6 text', 'avaxy'),
                        'subtitle' => __('Member percent6 text', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Photoshop'
                    ), 
                           array(
                        'id' => 'team_single_template',
                        'type' => 'editor',
                        'title' => __('team single template', 'avaxy'),
                        'subtitle' => __('team single template', 'avaxy'),
                        'default' => '',
                    ),
                           array(
                        'id' => 'text_mywork',
                        'type' => 'text',
                        'title' => __('text mywork', 'avaxy'),
                        'subtitle' => __('text mywork', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'mywork'
                    ),
                           array(
                        'id' => 'text_awesome',
                        'type' => 'text',
                        'title' => __('text awesome', 'avaxy'),
                        'subtitle' => __('text awesome', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'awesome'
                    ),
                           array(
                        'id' => 'sub_mywork',
                        'type' => 'text',
                        'title' => __('sub mywork', 'avaxy'),
                        'subtitle' => __('sub mywork', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut at elementum, ornare dui a, gravida dolor. Ut dictum ex eu velit molestie dapibus.'
                    ),

                 )
            ) );
        Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('FAQ Settings', 'avaxy'),
                'fields' => array(
                    array(
                        'id' => 'faq_text_top',
                        'type' => 'text',
                        'title' => __('FAQ text top', 'avaxy'),
                        'subtitle' => __('Input FAQ text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Rules'
                    ),
                    array(
                        'id' => 'faq_title',
                        'type' => 'text',
                        'title' => __('FAQ Title', 'avaxy'),
                        'subtitle' => __('Input FAQ Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'faq'
                    ),   
                    array(
                        'id' => 'faq_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('FAQ image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload FAQ image.', 'avaxy'),
                        'default' => ''
                    ),
                 )
            ) );
            
             
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Email Settings', 'avaxy'),
                'fields' => array(
                    
                    array(
                        'id' => 'email_receive',
                        'type' => 'text',
                        'title' => __('Email receive', 'avaxy'),
                        'subtitle' => __('Email receive in form', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'a@gmail.com'
                    ),  
                    
                 )
            ) );
               
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-graph',
                'title' => __('404 Settings', 'avaxy'),
                'fields' => array(
                    array(
                        'id' => '404_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('404 image background Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload page background image.', 'avaxy'),
                        'default' => ''
                    ),
                     array(
                        'id' => '404_title',
                        'type' => 'text',
                        'title' => __('404 Title', 'avaxy'),
                        'subtitle' => __('Input 404 Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '404'
                    ),  
                      array(
                        'id' => '404_text_top',
                        'type' => 'text',
                        'title' => __('404 text top', 'avaxy'),
                        'subtitle' => __('Input 404 text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Oops!'
                    ), 
                     array(
                        'id' => '404_subtitle',
                        'type' => 'text',
                        'title' => __('404 Sub Title', 'avaxy'),
                        'subtitle' => __('Input 404 Sub Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Page not found!'
                    ),
                    array(
                        'id' => '404_description',
                        'type' => 'text',
                        'title' => __('404 desc', 'avaxy'),
                        'subtitle' => __('Input 404 desc', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Oops! We’re sorry, the page you are looking for seems to be missing. Please report any broken links to our team. You can back to'
                    ),     
                      
                    array(
                        'id' => '404_button',
                        'type' => 'text',
                        'title' => __('404 Text button', 'avaxy'),
                        'subtitle' => __('Input 404 Text button', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'home page'
                    ), 
                               
                 )
            ) );

             Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-graph',
                'title' => __('403 Settings', 'avaxy'),
                'fields' => array(
                    array(
                        'id' => '403_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('403 image background Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload page background image.', 'avaxy'),
                        'default' => ''
                    ),
                     array(
                        'id' => '403_title',
                        'type' => 'text',
                        'title' => __('404 Title', 'avaxy'),
                        'subtitle' => __('Input 403 Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '403'
                    ),  
                      array(
                        'id' => '403_text_top',
                        'type' => 'text',
                        'title' => __('403 text top', 'avaxy'),
                        'subtitle' => __('Input 403 text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Oops!'
                    ), 
                     array(
                        'id' => '403_subtitle',
                        'type' => 'text',
                        'title' => __('403 Sub Title', 'avaxy'),
                        'subtitle' => __('Input 403 Sub Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Forbidden!'
                    ),
                    array(
                        'id' => '404_description',
                        'type' => 'text',
                        'title' => __('404 desc', 'avaxy'),
                        'subtitle' => __('Input 404 desc', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Oops! We’re sorry, you don’t have permission to view this page. Please report that to our team. You can back to'
                    ),     
                      
                    array(
                        'id' => '404_button',
                        'type' => 'text',
                        'title' => __('404 Text button', 'avaxy'),
                        'subtitle' => __('Input 404 Text button', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'home page'
                    ), 
                               
                 )
            ) );

             Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-graph',
                'title' => __('500 Settings', 'avaxy'),
                'fields' => array(
                    array(
                        'id' => '500_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('500 image background Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload page background image.', 'avaxy'),
                        'default' => ''
                    ),
                     array(
                        'id' => '500_title',
                        'type' => 'text',
                        'title' => __('500 Title', 'avaxy'),
                        'subtitle' => __('Input 500 Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '500'
                    ),  
                      array(
                        'id' => '500_text_top',
                        'type' => 'text',
                        'title' => __('500 text top', 'avaxy'),
                        'subtitle' => __('Input 500 text top', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Oops!'
                    ), 
                     array(
                        'id' => '500_subtitle',
                        'type' => 'text',
                        'title' => __('500 Sub Title', 'avaxy'),
                        'subtitle' => __('Input 500 Sub Title', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Sever error!'
                    ),
                    array(
                        'id' => '500_description',
                        'type' => 'text',
                        'title' => __('500 desc', 'avaxy'),
                        'subtitle' => __('Input 500 desc', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Oops! We’re sorry, something went wrong, We’re working on it and we’ll get it fixed as soon as we can. Please try it later. You can back to'
                    ),     
                      
                    array(
                        'id' => '500_button',
                        'type' => 'text',
                        'title' => __('500 Text button', 'avaxy'),
                        'subtitle' => __('Input 500 Text button', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'home page'
                    ), 
                               
                 )
            ) );
            
            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-credit-card',
                'title' => __('Header Settings', 'avaxy'),
                'fields' => array( 
                      
                    array(
                        'id' => 'header_phone',
                        'type' => 'text',
                        'title' => __('Phone', 'avaxy'),
                        'subtitle' => __('Phone', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Phone :'
                    ),  
                    array(
                        'id' => 'header_number',
                        'type' => 'text',
                        'title' => __('Phone number', 'avaxy'),
                        'subtitle' => __('Phone number', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '+1 (123) 456-7890'
                    ),
                    array(
                        'id' => 'header_mail',
                        'type' => 'text',
                        'title' => __('Mail', 'avaxy'),
                        'subtitle' => __('Mail', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Email :'
                    ),
                    array(
                        'id' => 'header_your_mail',
                        'type' => 'text',
                        'title' => __('your email', 'avaxy'),
                        'subtitle' => __('your email', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Support@Example.com'
                    ),
                    array(
                        'id' => 'header_link_facebook',
                        'type' => 'text',
                        'title' => __('link facebook', 'avaxy'),
                        'subtitle' => __('link facebook', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_twitter',
                        'type' => 'text',
                        'title' => __('link twitter', 'avaxy'),
                        'subtitle' => __('link twitter', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_google',
                        'type' => 'text',
                        'title' => __('link google', 'avaxy'),
                        'subtitle' => __('link google', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_youtube',
                        'type' => 'text',
                        'title' => __('link youtube', 'avaxy'),
                        'subtitle' => __('link youtube', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_behance',
                        'type' => 'text',
                        'title' => __('link behance', 'avaxy'),
                        'subtitle' => __('link behance', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_pinterest',
                        'type' => 'text',
                        'title' => __('link pinterest', 'avaxy'),
                        'subtitle' => __('link pinterest', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_dribbble',
                        'type' => 'text',
                        'title' => __('link dribbble', 'avaxy'),
                        'subtitle' => __('link dribbble', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_icon_facebook',
                        'type' => 'text',
                        'title' => __('icon facebook', 'avaxy'),
                        'subtitle' => __('icon facebook', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'fa fa-facebook'
                    ),
                    array(
                        'id' => 'header_icon_twitter',
                        'type' => 'text',
                        'title' => __('iconk twitter', 'avaxy'),
                        'subtitle' => __('icon twitter', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'fa fa-twitter'
                    ),
                    array(
                        'id' => 'header_icon_google',
                        'type' => 'text',
                        'title' => __('icon google', 'avaxy'),
                        'subtitle' => __('icon google', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'fa fa-google-plus'
                    ),
                    array(
                        'id' => 'header_icon_youtube',
                        'type' => 'text',
                        'title' => __('icon youtube', 'avaxy'),
                        'subtitle' => __('icon youtube', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'fa fa-youtube-play'
                    ),
                    array(
                        'id' => 'header_icon_behance',
                        'type' => 'text',
                        'title' => __('icon behance', 'avaxy'),
                        'subtitle' => __('icon behance', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'fa fa-behance'
                    ),
                    array(
                        'id' => 'header_icon_pinterest',
                        'type' => 'text',
                        'title' => __('icon pinterest', 'avaxy'),
                        'subtitle' => __('icon pinterest', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'fa fa-pinterest'
                    ),
                    array(
                        'id' => 'header_icon_dribbble',
                        'type' => 'text',
                        'title' => __('icon dribbble', 'avaxy'),
                        'subtitle' => __('icon dribbble', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'fa fa-dribbble'
                    ),
                    array(
                        'id' => 'header_slogan',
                        'type' => 'text',
                        'title' => __('Header slogan', 'avaxy'),
                        'subtitle' => __('Header slogan', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Multipurpose HTML5 Template'
                    ),
                    
                    array(
                        'id' => 'header_search',
                        'type' => 'text',
                        'title' => __('Text search', 'avaxy'),
                        'subtitle' => __('Text search', 'avaxy'),
                        'desc' => __('', 'avaxy'),
                        'default' => 'Type then press Enter or ESC to dismiss'
                    ),
                    array(
                        'id' => 'header_menu_text',
                        'type' => 'text',
                        'title' => __('Header menu text', 'avaxy'),
                        'subtitle' => __('Header menu text', 'avaxy'),
                        'default' => 'Menu',
                    ), 
                   
                )
            ) );
            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-credit-card',
                'title' => __('Footer Settings', 'avaxy'),
                'fields' => array(  
                    array(
                        'id' => 'footer_text',
                        'type' => 'editor',
                        'title' => __('Footer Text Left', 'avaxy'),
                        'subtitle' => __('Copyright Text Left', 'avaxy'),
                        'default' => '© 2015 avaxy, All Rights Reserved. Crafted with by NestoLab',
                    ), 
                    array(
                        'id' => 'footer_template',
                        'type' => 'editor',
                        'title' => __('Footer template', 'avaxy'),
                        'subtitle' => __('Footer template', 'avaxy'),
                        'default' => '',
                    ), 
                    
                )
            ) );


            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-credit-card',
                'title' => __('Home BG slider', 'avaxy'),
                'fields' => array( 
                    array(
                        'id' => 'slider_image1',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('slider image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload slider image.', 'avaxy'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'slider_image2',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('slider image Upload', 'avaxy'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'avaxy'),
                        'subtitle' => __('Upload slider image.', 'avaxy'),
                        'default' => ''
                    ),      
                    
                )
            ) );
            
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-website',
                'title' => __('Styling Options', 'avaxy'),
                'fields' => array(
                    array(
                            'id' => 'header_bg',
                            'type' => 'media',
                            'url' => true,
                            'title' => __('Background header', 'avaxy'),
                            'compiler' => 'true',
                            //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                            'desc' => __('', 'avaxy'),
                            'subtitle' => __('Upload your background header.', 'avaxy'),
                            'default' => ''
                        ),
                    array(
                        'id' => 'rtl',
                        'type' => 'checkbox',
                        'title' => __('Support RTL language', 'avaxy'),
                        'subtitle' => '',
                        'desc' => '',
                        'default' => '0'// 1 = on | 0 = off
                    ),
                    array(
                        'id' => 'chosen-color',
                        'type' => 'checkbox',
                        'title' => __('Enable edit color', 'avaxy'),
                        'subtitle' => '',
                        'desc' => '',
                        'default' => '0'// 1 = on | 0 = off
                    ),
                    array(
                        'id' => 'main-color-1',
                        'type' => 'color',
                        'title' => __('Theme Main Color 1', 'avaxy'),
                        'subtitle' => __('Pick the main color for the theme (default: #FBB12F).', 'avaxy'),
                        'default' => '#FBB12F',
                        'validate' => 'color',
                    ),  
                    array(
                        'id' => 'main-color-2',
                        'type' => 'color',
                        'title' => __('Theme Main Color 2', 'avaxy'),
                        'subtitle' => __('Pick the main color for the theme (default: #1FB5C7).', 'avaxy'),
                        'default' => '#1FB5C7',
                        'validate' => 'color',
                    ), 
                    
                    
                    array(
                        'id' => 'body-font2',
                        'type' => 'typography',
                        'output' => array('body'),
                        'title' => __('Body Font', 'avaxy'),
                        'subtitle' => __('Specify the body font properties.', 'avaxy'),
                        'google' => true,
                        'default' => array(
                            'color' => '#808080',
                            'font-size' => '14px',
                            'line-height' => '26px',
                            'font-family' => '"Open Sans", sans-serif',
                        ),
                    ),
                     array(
                        'id' => 'custom-css',
                        'type' => 'ace_editor',
                        'title' => __('CSS Code', 'avaxy'),
                        'subtitle' => __('Paste your CSS code here.', 'avaxy'),
                        'mode' => 'css',
                        'theme' => 'monokai',
                        'desc' => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',
                        'default' => "#header{\nmargin: 0 auto;\n}"
                    ),
                )
            ) );

    if ( file_exists( dirname( __FILE__ ) . '/../README.md' ) ) {
        $section = array(
            'icon'   => 'el el-list-alt',
            'title'  => __( 'Documentation', 'redux-framework-demo' ),
            'fields' => array(
                array(
                    'id'       => '17',
                    'type'     => 'raw',
                    'markdown' => true,
                    'content_path' => dirname( __FILE__ ) . '/../README.md', // FULL PATH, not relative please
                    //'content' => 'Raw content here',
                ),
            ),
        );
        Redux::setSection( $opt_name, $section );
    }
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', 'redux-framework-demo' ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-framework plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

